{% extends 'django_spire/navigation/accordion/nav_accordion.html' %}

{% block nav_title %}
    Permission
{% endblock %}

{% block nav_icon %}bi bi-gear-fill{% endblock %}

{% block accordion_links %}
    {% if perms.django_spire_auth_group.view_authgroup %}
        {% url 'django_spire:auth:group:page:list' as group_list_url %}
        {% include 'django_spire/navigation/elements/nav_link.html' with link_text='Groups' link_icon='bi bi-people' link_url=group_list_url %}
    {% endif %}

    {% if perms.django_spire_auth_user.view_authuser %}
        {% url 'django_spire:auth:user:page:list' as user_list_url %}
        {% include 'django_spire/navigation/elements/nav_link.html' with link_text='Users' link_icon='bi bi-person-badge' link_url=user_list_url %}
    {% endif %}
{% endblock %}
