{% if is_active %}
    {% include 'django_spire/badge/success_badge.html' with badge_text='Active' %}
{% else %}
    {% include 'django_spire/badge/danger_badge.html' with badge_text='Inactive' %}
{% endif %}
