__VERSION__ = '0.16.12'


AI_CHAT_WORKFLOW_SENDER_SETTINGS_NAME = 'AI_CHAT_WORKFLOW_NAME'
AI_CHAT_WORKFLOW_CLASS_SETTINGS_NAME = 'AI_CHAT_WORKFLOW_CLASS'
AI_SMS_CONVERSATION_WORKFLOW_CLASS_SETTINGS_NAME = 'AI_SMS_CONVERSATION_WORKFLOW_CLASS'


MAINTENANCE_MODE_SETTINGS_NAME = 'MAINTENANCE_MODE'

NOTIFICATION_THROTTLE_RATE_PER_MINUTE_SETTINGS_NAME = 'NOTIFICATION_THROTTLE_RATE_PER_MINUTE'
