<div x-data="{
    load_chat_from_search(chat_id) {
        load_chat(chat_id)
        load_recent_chats()
    }
}" class="row m-0">
    <div class="col-12">

        {% for search_result in search_results %}

            <div class="row py-2">
                <div class="col pt-2">
                    {{ search_result.name }}
                </div>
                <div class="col-auto">
                    <span class="btn btn-app-primary" @click="load_chat_from_search('{{ search_result.id }}')">
                        <i class="bi bi-chat-dots-fill"></i>
                    </span>
                </div>
            </div>

        {% endfor %}

    </div>
</div>
