<form method="post">
    <div
        x-data="{
            async init() {
                await this.group.get()
            },
            group: new ModelObjectGlue('group')
        }"
        class="row">
            {% csrf_token %}
            <div class="col-4 mb-2">
                {% include 'django_glue/form/field/char_field.html' with glue_model_field='group.name' %}
            </div>
            <div class="col-12">
                {% include 'django_spire/contrib/form/button/form_submit_button.html' %}
            </div>
    </div>

</form>
