[data-theme="dark"] {
    --app-primary: #82aaff;
    --app-primary-soft: #444267;
    --app-primary-dark: #5c7cfa;

    --app-secondary: #676e95;
    --app-secondary-soft: #444267;
    --app-secondary-dark: #5a6394;

    --app-accent: #f78c6c;
    --app-accent-soft: #444267;
    --app-accent-dark: #ff8a65;

    --app-success: #c3e88d;
    --app-success-soft: #444267;
    --app-success-dark: #a5e075;

    --app-warning: #ffcb6b;
    --app-warning-soft: #444267;
    --app-warning-dark: #ffc947;

    --app-danger: #f07178;
    --app-danger-soft: #444267;
    --app-danger-dark: #ff5370;

    --app-layer-one: #1e1e2e;
    --app-layer-two: #444267;
    --app-layer-three: #4e5579;
    --app-layer-four: #676e95;

    --app-alt-layer-one: #1a1a2e;
    --app-alt-layer-two: #353759;
    --app-alt-layer-three: #3e4267;
    --app-alt-layer-four: #575c7c;

    --app-default-attribute-title-color: #a6accd;
    --app-default-button-text-color: #292d3e;
    --app-default-text-color: #a6accd;
    --app-default-alt-text-color: #959dcb;
    --app-default-link-color: #82aaff;
    --app-default-link-hover-color: #c792ea;

    --app-side-navigation-bg-color: #1e1e2e;
    --app-side-navigation-text-color: #a6accd;
    --app-side-navigation-link-color: #a6accd;
    --app-side-navigation-link-hover-color: #82aaff;
    --app-side-navigation-width: 200px;

    --app-mobile-navigation-width: 200px;

    --app-top-navigation-bg-color: #1e1e2e;
    --app-top-navigation-text-color: #a6accd;
    --app-top-navigation-link-color: #82aaff;
    --app-top-navigation-link-hover-color: #c792ea;
    --app-top-navigation-height: 100px;

    --app-footer-bg-color: #1e1e2e;
    --app-footer-text-color: #a6accd;
    --app-footer-link-color: #82aaff;
    --app-footer-link-hover-color: #c792ea;

    --app-table-row-color: #292d3e;
    --app-table-row-alt-color: #444267;
    --app-table-row-hover-color: #4e5579;

    --bs-border-color: #4e5579;

    --app-shadow-light: rgba(0, 0, 0, 0.2);
    --app-shadow-medium: rgba(0, 0, 0, 0.4);
    --app-shadow-heavy: rgba(0, 0, 0, 0.6);
    --app-shadow-navigation: rgba(0, 0, 0, 0.8);

    --app-border-translucent-light: rgba(78, 85, 121, 0.175);
    --app-focus-ring-primary: rgba(130, 170, 255, 0.25);
}
