{% load static %}

<div class="navbar sticky-top bg-app-side-navigation d-block" style="width: 100%; height: 100vh">
    <div class="text-center pt-2">
        {% block side_navigation_top_content %}
            <div class="text-center d-flex justify-content-center">
                {% block side_navigation_img %}
                    <img src="{% static 'img/django_spire.svg' %}" class="w-side-navigation-img"
                         alt="Django Spire Logo">
                {% endblock %}
            </div>
        {% endblock %}
    </div>

    <div class="navbar-nav-scroll scrollbar-hidden p-2">
        {% block side_navigation_links %}
            {% include 'django_spire/navigation/navigation_links.html' %}
        {% endblock %}
    </div>
</div>
